Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(311)

Unified Diff: net/http/http_network_session.h

Issue 1808303005: QUIC - extend origin-to-force-quic-on command line option to accept list (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed comments for Patch Set 1 Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/chrome_switches.cc ('k') | net/http/http_network_session.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_network_session.h
diff --git a/net/http/http_network_session.h b/net/http/http_network_session.h
index 094eea8a1f77231ec143275e330c9ce7e869ac8e..7970146bb393a8514fe4f2957561d185c38123df 100644
--- a/net/http/http_network_session.h
+++ b/net/http/http_network_session.h
@@ -146,8 +146,9 @@ class NET_EXPORT HttpNetworkSession
// Maximum number of server configs that are to be stored in
// HttpServerProperties, instead of the disk cache.
size_t quic_max_server_configs_stored_in_properties;
- // If not empty, QUIC will be used for all connections to this origin.
- HostPortPair origin_to_force_quic_on;
+ // If not empty, QUIC will be used for all connections to the set of
+ // origins in |origins_to_force_quic_on|.
+ std::set<HostPortPair> origins_to_force_quic_on;
// Source of time for QUIC connections. Will be owned by QuicStreamFactory.
QuicClock* quic_clock;
// Source of entropy for QUIC connections.
« no previous file with comments | « chrome/common/chrome_switches.cc ('k') | net/http/http_network_session.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698